@@ -10,13 +10,17 @@ use Cache::Memcached;
 
 WWW::Session::Storage::Memcached - Memcached storage for WWW::Session
 
+=head1 DESCRIPTION
+
+Memcached backend for WWW::Session
+
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 
 =head1 SYNOPSIS
